@@ -93,4 +93,12 @@ test_that("reported issues are solved",{
   exprs_s <- to_exprs(rules_s)
   expect_equal(exprs_s[[1]], quote( 0 > a))
 })
+
+test_that('Ton issue 11',{
+  rules <- validator(r1 = if (A == "1") B == TRUE)
+  rules_s <- substitute_values(rules, A = "1")
+  exprs_s <- to_exprs(rules_s)
+  expect_equal(exprs_s$r1, quote(B == TRUE))
+  expect_equal(exprs_s$.const_A, quote(A == "1"))
+})
   
\ No newline at end of file
